@@ -69,7 +69,7 @@ class AutoInt(BaseModel):
                            activation=dnn_activation, l2_reg=l2_reg_dnn, dropout_rate=dnn_dropout, use_bn=dnn_use_bn,
                            init_std=init_std, device=device)
             self.add_regularization_weight(
-                filter(lambda x: 'weight' in x[0] and 'bn' not in x[0], self.dnn.named_parameters()), l2_reg_dnn)
+                filter(lambda x: 'weight' in x[0] and 'bn' not in x[0], self.dnn.named_parameters()), l2=l2_reg_dnn)
         self.int_layers = nn.ModuleList(
             [InteractingLayer(self.embedding_size if i == 0 else att_embedding_size * att_head_num,
                               att_embedding_size, att_head_num, att_res, device=device) for i in range(att_layer_num)])
